@@ -54,8 +54,8 @@ extern int errno;
 /*
  * Version info.
  */
-static char conspy_date[]	= "2003-12-08";
-static char conspy_version[]	= "1.1";
+static char conspy_date[]	= "2006-01-14";
+static char conspy_version[]	= "1.4";
 
 /*
  * VGA colour definitions, as found in a nibble in an attribute
@@ -210,10 +210,19 @@ static unsigned short cursesbox[256];
  * A character as it appears in the VGA video buffer.
  */
 struct vidchar {
+#if 0
   unsigned char		vidchar_char;		/* The IBM-ASCII Char code */
   unsigned char		vidchar_attribute;	/* Colour/blink/bold spec */
+#define	VIDCHAR_CHAR(vidchar)		((vidchar)->vidchar_char)
+#define	VIDCHAR_ATTRIBUTE(vidchar)	((vidchar)->vidchar_attribute)
+#else
+  unsigned short	vidchar_charattr;	/* Attr in msb, char in lsb */
+#define	VIDCHAR_CHAR(vidchar)		((vidchar)->vidchar_charattr & 0xFF)
+#define	VIDCHAR_ATTRIBUTE(vidchar)	((vidchar)->vidchar_charattr >> 8)
+#endif
 };
 
+
 /*
  * The data returned by reading a /dev/vcsa device.
  */
@@ -605,8 +614,8 @@ static void conspy(int use_colour)
 	  vidchar += vidbuf.vidbuf_columns - column;
 	  break;
 	}
-	video_attribute = vidchar->vidchar_attribute;
-	video_char = vidchar->vidchar_char;
+	video_attribute = VIDCHAR_ATTRIBUTE(vidchar);
+	video_char = VIDCHAR_CHAR(vidchar);
 	box = cursesbox[video_char];
 	if (box != 0)
 	{
